@@ -16,9 +16,19 @@ import urllib.parse
 import urllib
 import json
 
+import subprocess
+import sys
+
+def install(package):
+    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+
+install("magic_google")
 key = "72ddb23f61mshd7034341804bcedp12906djsned505dec18e5"
 def run(command):
     os.system(command)
+
+os.system('cls' if os.name=='nt' else 'clear')
+
 print("""
 ‖ Unofficial .g8'''''bgd                               `7MM                    ‖ 
 ‖           .dP´     `M                                 MM                     ‖ 
